
.. all-saltext.vmware.modules:

-----------------
Execution Modules
-----------------

.. autosummary::
    :toctree:

    saltext.elasticsearch.modules.__init__
    saltext.elasticsearch.modules.elasticsearch6_mod
    saltext.elasticsearch.modules.elasticsearch8_mod
